@@ -2,7 +2,7 @@
 // stream_descriptor_service.cpp
 // ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2008 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2013 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -16,12 +16,10 @@
 // Test that header file is self-contained.
 #include "asio/posix/stream_descriptor_service.hpp"
 
-#include "asio.hpp"
 #include "../unit_test.hpp"
 
-test_suite* init_unit_test_suite(int, char*[])
-{
-  test_suite* test = BOOST_TEST_SUITE("posix/stream_descriptor_service");
-  test->add(BOOST_TEST_CASE(&null_test));
-  return test;
-}
+ASIO_TEST_SUITE
+(
+  "posix/stream_descriptor_service",
+  ASIO_TEST_CASE(null_test)
+)
